@@ -6,10 +6,13 @@ class PyPITokenException(Exception):
     """
 
 
-class LoadError(PyPITokenException):
+class LoaderError(PyPITokenException):
     """
     Exception encoutered while calling `Token.load`, due to unexpected
     format.
+
+    Exception should be associated with a message in English that can be shown to the
+    bearer to explain the error.
     """
 
 
@@ -17,16 +20,7 @@ class ValidationError(PyPITokenException):
     """
     Exception encoutered while calling `Token.check`, the token should
     be considered invalid.
-    """
 
-
-class MissingContextError(ValidationError, NotImplementedError):
-    """
-    Token check failed du to missing information in the passed context.
-
-    The token should be considered invalid, but this is likely a problem in the
-    implementing code: we most likely forgot a context element.
-
-    Due to PyMacaroons & this lib implementation details, this exception is currently
-    not fired by `Token.check`.
+    Exception should be associated with a message in English that can be shown to the
+    bearer to explain the error.
     """
